set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_Table8, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Table 8 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
             Note that within-R2 calculated in a seperate .do file:
                diGiovanni_Levchenko_Comovement_AEJmacro_Table8_R2.do
        
             Specification 1: pooled ij & ii
         
             Specification 2: polled with same/diff't sector split (no IO)

             Specification 3: pooled with IO.

             Specification 4: pooled with IO*ii/ij interaction
*/

clear

set mem 10g
set matsize 10000


/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country pair type
        ltrade: sum of `2' & `3'
*/

capture program drop reg_table1
program define reg_table1
    ge ltrade = `2'+`3'
     
    * Pooled
    
    reg `1' ltrade, robust 
    outreg using `4'_`1'_`2'_table1, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade  using `4'_`1'_`2'_table1, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS+ISIC") 

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade i.cs2, abs(cs1) robust 
    outreg ltrade  using `4'_`1'_`2'_table1, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS*ISIC") 

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade  using `4'_`1'_`2'_table1, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS^2+ISIC^2") 

    drop ltrade
end


/* 
    Program for table2 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country pair type
        ltrade: sum of `2' & `3'
        ss_ltrade: ssec*ltrade
*/

capture program drop reg_table2
program define reg_table2
    ge ltrade = `2'+`3'
    ge ss_ltrade = ssec*ltrade
     
    * Pooled
    
    reg `1' ltrade ss_ltrade ssec, robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg using `4'_`1'_`2'_table2, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade ssec using `4'_`1'_`2'_table2, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS+ISIC")
    
    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.cs2, abs(cs1) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade ssec using `4'_`1'_`2'_table2, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS*ISIC")

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade i.pid_isic, abs(pid_ifs) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade using `4'_`1'_`2'_table2, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS^2+ISIC^2")
        
    drop ltrade
    drop ss_ltrade
end


/* 
    Program for table3 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        `6': country pair type
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
*/


capture program drop reg_table3
program define reg_table3
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'

    * Pooled
    
    reg `1' ltrade ltrade_io io, robust 
    outreg using `6'_`1'_`2'_table3, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade ltrade_io io using `6'_`1'_`2'_table3, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS+ISIC") 

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.cs2, abs(cs1) robust 
    outreg ltrade ltrade_io io using `6'_`1'_`2'_table3, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS*ISIC") 
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ltrade_io i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade ltrade_io using `6'_`1'_`2'_table3, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS^2+ISIC^2") 
    
    drop ltrade
    drop io
    drop ltrade_io
end


/* 
    Program for table4 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        `6': country pair type
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
        ss_ltrade: ssec*ltrade
        ss_ltrade_io: (`2'*`4' + `3'*`5')*ssec
*/

capture program drop reg_table4
program define reg_table4
    sum `1' `2' `3' `4' `5'
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'
    ge ss_ltrade = ssec*ltrade
    ge ss_io = ssec*io
    ge ss_ltrade_io = (`2'*`4' + `3'*`5')*ssec

    * Pooled
    
    reg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io, robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg using `6'_`1'_`2'_table4, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io using `6'_`1'_`2'_table4, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS+ISIC")

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade  ltrade_io ss_io ss_ltrade_io ssec io  i.cs2, abs(cs1) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io using `6'_`1'_`2'_table4, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS*ISIC")
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io i.pid_isic, abs(pid_ifs) robust 
    lincom ltrade+ss_ltrade
    local b = r(estimate)
    local se = r(se)
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io using `6'_`1'_`2'_table4, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS^2+ISIC^2")
    
    drop ltrade
    drop io
    drop ss_ltrade
    drop ltrade_io ss_io
    drop ss_ltrade_io
end



/*****************************/

* Define local variables to feed into regressions

local LHS "corr_12"
local RHS "lbiexports_gdp"
local FEfiles "table1 table2 table3 table4"
local IOvars "IO_USA"

********************************************************************************
* OECD-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

quietly do oecd_dummy
keep if oecd1==1 & oecd2==1

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

* Initialize outreg files so that can simply add on afterwords, so ignore first column

quietly foreach X of local LHS{
    foreach Y of local FEfiles{
        foreach Z of local RHS{
            reg ifscode1 ifscode2
            outreg using oo_`X'_`Z'1_`Y', replace coef 10pct bdec(4) rdec(3) se nolabel 
        }   
    }
}
 
* Table 1

foreach Y of local LHS{
    foreach X of local RHS{
        reg_table1 `Y' `X'1 `X'2 oo
    }
}

* Table 2

foreach Y of local LHS{
    foreach X of local RHS{
        reg_table2 `Y' `X'1 `X'2 oo
    }
}

* Table 3

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2 oo
        }
    }
}
 
* Table 4

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2 oo
        }
    }
}

********************************************************************************
* non-OECD-non-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

quietly do oecd_dummy
keep if oecd1==0 & oecd2==0

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

* Initialize outreg files so that can simply add on afterwords, so ignore first column

quietly foreach X of local LHS{
    foreach Y of local FEfiles{
        foreach Z of local RHS{
            reg ifscode1 ifscode2
            outreg using nn_`X'_`Z'1_`Y', replace coef 10pct bdec(4) rdec(3) se nolabel 
        }   
    }
}
 
* Table 1

foreach Y of local LHS{
    foreach X of local RHS{
		reg_table1 `Y' `X'1 `X'2 nn

    }
}

* Table 2

foreach Y of local LHS{
    foreach X of local RHS{
		reg_table2 `Y' `X'1 `X'2 nn
    }
}

* Table 3

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2 nn
        }
    }
}
 
* Table 4

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2 nn
        }
    }
}


********************************************************************************
* OECD-non-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

quietly do oecd_dummy
keep if (oecd1==1 & oecd2==0) | (oecd1==0 & oecd2==1)

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

* Initialize outreg files so that can simply add on afterwords, so ignore first column

quietly foreach X of local LHS{
    foreach Y of local FEfiles{
        foreach Z of local RHS{
            reg ifscode1 ifscode2
            outreg using on_`X'_`Z'1_`Y', replace coef 10pct bdec(4) rdec(3) se nolabel 
        }   
    }
}
 
* Table 1

foreach Y of local LHS{
    foreach X of local RHS{
		reg_table1 `Y' `X'1 `X'2 on
    }
}

* Table 2

foreach Y of local LHS{
    foreach X of local RHS{
		reg_table2 `Y' `X'1 `X'2 on
    }
}

* Table 3

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2 on
        }
    }
}
 
* Table 4

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2 on
        }
    }
}

log close 
