set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_Tables1_5_R2, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces the within-R2 of Tables 1-5 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
        
             Regression Table 1: pooled ij & ii
         
             Regression Table 2: polled with same/diff't sector split (no IO)

             Regression Table 3: pooled with IO.

             Regression Table 4: pooled with IO*ii/ij interaction

             Regression Table 5: IO and Luong & BW elasticity
*/

clear

set mem 10g
set matsize 10000

use ../Data/indx_data_corrij_final

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

/*
   Program for  RSS of main regression
*/

capture program drop rss_n
program define rss_n
    mat rss = e(rss)
    svmat rss
    egen rss_n = mean(rss1)
    local rss_n = rss_n
    mat rss_n = `rss_n'
    drop rss1 rss_n
end
 
/*
   Program for  RSS of dummy regression
*/

capture program drop rss_d
program define rss_d
    mat rss = e(rss)
    svmat rss
    egen rss_d = mean(rss1)
    local rss_d = rss_d
    mat rss_d = `rss_d'
    drop rss1 rss_d
end

/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        ltrade: sum of `2' & `3'
*/

capture program drop reg_table1
program define reg_table1
    ge ltrade = `2'+`3'

    mat R2_`2'_1 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' ltrade i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_1[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade i.cs1, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_1[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade i.pid_isic, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_1[1,3] = 1 - rss_n[1,1]/rss_d[1,1]

    drop ltrade
end


/* 
    Program for table2 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        ltrade: sum of `2' & `3'
        ss_ltrade: ssec*ltrade
*/

capture program drop reg_table2
program define reg_table2
    ge ltrade = `2'+`3'
    ge ss_ltrade = ssec*ltrade
     
    mat R2_`2'_2 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_2[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.cs1, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_2[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade i.pid_isic, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_2[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                        
    drop ltrade
    drop ss_ltrade
end


/* 
    Program for table3 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
*/


capture program drop reg_table3
program define reg_table3
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'

    mat R2_`2'_3 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_3[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.cs1, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_3[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ltrade_io i.pid_isic, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_3[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
        
    drop ltrade
    drop io
    drop ltrade_io
end


/* 
    Program for table4 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
        ss_ltrade: ssec*ltrade
        ss_ltrade_io: (`2'*`4' + `3'*`5')*ssec
*/

capture program drop reg_table4
program define reg_table4
    sum `1' `2' `3' `4' `5'
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'
    ge ss_ltrade = ssec*ltrade
    ge ss_io = ssec*io
    ge ss_ltrade_io = (`2'*`4' + `3'*`5')*ssec

    mat R2_`2'_4 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_4[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io i.cs1, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_4[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io  i.pid_isic, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_4[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                
    drop ltrade
    drop io
    drop ss_ltrade
    drop ltrade_io ss_io
    drop ss_ltrade_io
end


/* 
    Program for table5 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        `6': country 1's elasticity
        `7': country 2's elasticity
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        elasticity: sum of `6' & `7'
        ltrade_io: `2'*`4' + `3'*`5'
        ltrade_elas:  `2'*`7' + `3'*`6'
*/

capture program drop reg_table5
program define reg_table5
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge elasticity = `6'+`7'
    ge ltrade_io = `2'*`4' + `3'*`5'
    ge ltrade_elast = `2'*`7' + `3'*`6'

    mat R2_`2'_5 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ltrade_io ltrade_elast io elasticity i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_5[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ltrade_io ltrade_elast io elasticity i.cs1, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_5[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ltrade_io ltrade_elast i.pid_isic, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_5[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                
    drop ltrade
    drop io
    drop ltrade_io
    drop elasticity
    drop ltrade_elast
end

/*****************************/


* Define local variables to feed into regressions

local LHS "corr_12"
local RHS "lbiexports_gdp lbiexports_output lbiexports_secexports lbiexports_totexports"
local FEfiles "table1 table2 table3 table4 table5"
local IOvars "IO_USA"


* Table 1

mat R2_1 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table1 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}
mat R2_1[1,1] = R2_lbiexports_gdp1_1
mat R2_1[2,1] = R2_lbiexports_output1_1
mat R2_1[3,1] = R2_lbiexports_secexports1_1
mat R2_1[4,1] = R2_lbiexports_totexports1_1

svmat R2_1
outsheet R2_1* using Table1_R2, replace

* Table 2

mat R2_2 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table2 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_2[1,1] = R2_lbiexports_gdp1_2
mat R2_2[2,1] = R2_lbiexports_output1_2
mat R2_2[3,1] = R2_lbiexports_secexports1_2
mat R2_2[4,1] = R2_lbiexports_totexports1_2

svmat R2_2
outsheet R2_2* using Table2_R2, replace

* Table 3

mat R2_3 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_3[1,1] = R2_lbiexports_gdp1_3
mat R2_3[2,1] = R2_lbiexports_output1_3
mat R2_3[3,1] = R2_lbiexports_secexports1_3
mat R2_3[4,1] = R2_lbiexports_totexports1_3

svmat R2_3
outsheet R2_3* using Table3_R2, replace

 
* Table 4

mat R2_4 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_4[1,1] = R2_lbiexports_gdp1_4
mat R2_4[2,1] = R2_lbiexports_output1_4
mat R2_4[3,1] = R2_lbiexports_secexports1_4
mat R2_4[4,1] = R2_lbiexports_totexports1_4

svmat R2_4
outsheet R2_4* using Table4_R2, replace


* Table 5 - BW

local ELAST "elasticity_bw"

mat R2_5 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            foreach Q of local ELAST{
                reg_table5 `Y' `X'1 `X'2 `Z'1 `Z'2 `Q'1 `Q'2
            }
        }
    }
}

mat R2_5[1,1] = R2_lbiexports_gdp1_5
mat R2_5[2,1] = R2_lbiexports_output1_5
mat R2_5[3,1] = R2_lbiexports_secexports1_5
mat R2_5[4,1] = R2_lbiexports_totexports1_5

svmat R2_5
outsheet R2_5* using Table5_R2_BW, replace

* Table 5 - Luong

local ELAST "elasticity_luong"

mat R2_5 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            foreach Q of local ELAST{
                reg_table5 `Y' `X'1 `X'2 `Z'1 `Z'2 `Q'1 `Q'2
            }
        }
    }
}

mat R2_5[1,1] = R2_lbiexports_gdp1_5
mat R2_5[2,1] = R2_lbiexports_output1_5
mat R2_5[3,1] = R2_lbiexports_secexports1_5
mat R2_5[4,1] = R2_lbiexports_totexports1_5

svmat R2_5
outsheet R2_5* using Table5_R2_Luong, replace

log close 
